@@ -9,7 +9,10 @@ effects.windowAdded.connect(function (window) {
         keepAlive: false
     });
 
-    window.windowMinimized.connect(() => {
+    window.minimizedChanged.connect(() => {
+        if (!window.minimized) {
+            return;
+        }
         if (redirect(window.animation, Effect.Backward, Effect.TerminateAtSource)) {
             sendTestResponse('ok');
         } else {
