@@ -51,8 +51,8 @@ void TestFractionalScale::initTestCase()
     qRegisterMetaType<KWin::Window *>();
     qRegisterMetaType<KWayland::Client::Output *>();
 
-    QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(waylandServer()->init(s_socketName));
+    kwinApp()->start();
     Test::setOutputConfig({
         Test::OutputInfo{
             .geometry = QRect(0, 0, 1280 / 1.25, 1024 / 1.25),
@@ -63,9 +63,6 @@ void TestFractionalScale::initTestCase()
             .scale = 2.0,
         },
     });
-
-    kwinApp()->start();
-    QVERIFY(applicationStartedSpy.wait());
     const auto outputs = workspace()->outputs();
     QCOMPARE(outputs.count(), 2);
     QCOMPARE(outputs[0]->geometry(), QRect(0, 0, 1024, 819));
