@@ -46,7 +46,7 @@ public:
     InputCapture()
     {
         auto msg = QDBusMessage::createMethodCall(QDBusConnection::sessionBus().baseService(), kwinInputCapturePath, kwinInputCaptureManagerInterface, QStringLiteral("addInputCapture"));
-        msg << static_cast<int>(PortalCapabilities::All);
+        msg << static_cast<uint>(PortalCapabilities::All);
         QDBusReply<QDBusObjectPath> captureReply = QDBusConnection::sessionBus().call(msg);
         QVERIFY2(captureReply.isValid(), QTest::toString(captureReply.error()));
         dbusPath = captureReply.value().path();
@@ -105,8 +105,8 @@ void TestInputCapture::cleanup()
 void TestInputCapture::initTestCase()
 {
     QVERIFY(waylandServer()->init(s_socketName));
-    Test::setOutputConfig({QRect(0, 0, 1280, 1024)});
     kwinApp()->start();
+    Test::setOutputConfig({QRect(0, 0, 1280, 1024)});
     QVERIFY(kwinApp()->pluginManager()->loadedPlugins().contains("eis"));
 }
 
@@ -295,8 +295,12 @@ void TestInputCapture::testInputCapture()
     QCOMPARE(input()->globalPointer(), QPoint(1, 1));
 
     QVERIFY(eiReadableSpy.wait());
-    ei_dispatch(ei);
     eiReadableSpy.clear();
+    ei_dispatch(ei);
+    // Throw away the disconnection events
+    while (auto event = ei_get_event(ei)) {
+        ei_event_unref(event);
+    }
 
     Test::pointerMotion({2, 2}, ++timestamp);
     Test::pointerButtonPressed(BTN_LEFT, ++timestamp);
@@ -308,7 +312,11 @@ void TestInputCapture::testInputCapture()
     QVERIFY(buttonSpy.count());
     QVERIFY(axisSpy.count());
     QVERIFY(keySpy.count());
-    QVERIFY(eiReadableSpy.empty());
+
+    if (!eiReadableSpy.empty()) {
+        ei_dispatch(ei);
+        QVERIFY(!ei_peek_event(ei));
+    }
 
     msg = QDBusMessage::createMethodCall(QDBusConnection::sessionBus().baseService(), kwinInputCapturePath, kwinInputCaptureManagerInterface, QStringLiteral("removeInputCapture"));
     msg << QDBusObjectPath(capture.dbusPath);
