@@ -15,6 +15,7 @@
 #include "window.h"
 #include "workspace.h"
 
+#include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/output.h>
 #include <KWayland/Client/surface.h>
 
@@ -56,19 +57,18 @@ private Q_SLOTS:
     void testUnmap();
     void testScreenEdge_data();
     void testScreenEdge();
+    void testUnconfiguredBuffer();
 };
 
 void LayerShellV1WindowTest::initTestCase()
 {
-    QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(waylandServer()->init(s_socketName));
+
+    kwinApp()->start();
     Test::setOutputConfig({
         QRect(0, 0, 1280, 1024),
         QRect(1280, 0, 1280, 1024),
     });
-
-    kwinApp()->start();
-    QVERIFY(applicationStartedSpy.wait());
     const auto outputs = workspace()->outputs();
     QCOMPARE(outputs.count(), 2);
     QCOMPARE(outputs[0]->geometry(), QRect(0, 0, 1280, 1024));
@@ -845,6 +845,21 @@ void LayerShellV1WindowTest::testScreenEdge()
     }
 }
 
+void LayerShellV1WindowTest::testUnconfiguredBuffer()
+{
+    // This test verifies that a protocol error is posted when a client attaches a buffer to
+    // the initial commit.
+
+    std::unique_ptr<KWayland::Client::Surface> surface(Test::createSurface());
+    std::unique_ptr<Test::LayerSurfaceV1> shellSurface(Test::createLayerSurfaceV1(surface.get(), QStringLiteral("test")));
+    shellSurface->set_anchor(Test::LayerSurfaceV1::anchor_bottom);
+    shellSurface->set_size(100, 50);
+    Test::render(surface.get(), QSize(100, 50), Qt::blue);
+
+    QSignalSpy connectionErrorSpy(Test::waylandConnection(), &KWayland::Client::ConnectionThread::errorOccurred);
+    QVERIFY(connectionErrorSpy.wait());
+}
+
 } // namespace KWin
 
 WAYLANDTEST_MAIN(KWin::LayerShellV1WindowTest)
