@@ -35,12 +35,10 @@ private Q_SLOTS:
 
 void ScreenChangesTest::initTestCase()
 {
-    QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(waylandServer()->init(s_socketName));
-    Test::setOutputConfig({QRect(0, 0, 1280, 1024)});
 
     kwinApp()->start();
-    QVERIFY(applicationStartedSpy.wait());
+    Test::setOutputConfig({QRect(0, 0, 1280, 1024)});
     setenv("QT_QPA_PLATFORM", "wayland", true);
 }
 
