@@ -1,9 +1,9 @@
 function init() {
-    var edge = readConfig("Edge", 1);
+    const edge = readConfig("Edge", 1);
     if (readConfig("mode", "") == "unregister") {
         unregisterScreenEdge(edge);
     } else {
-        registerScreenEdge(edge, function() { workspace.slotToggleShowDesktop(); });
+        registerScreenEdge(edge, workspace.slotToggleShowDesktop);
     }
 }
 options.configChanged.connect(init);
