@@ -60,15 +60,13 @@ private:
 void TouchInputTest::initTestCase()
 {
     qRegisterMetaType<KWin::Window *>();
-    QSignalSpy applicationStartedSpy(kwinApp(), &Application::started);
     QVERIFY(waylandServer()->init(s_socketName));
+
+    kwinApp()->start();
     Test::setOutputConfig({
         QRect(0, 0, 1280, 1024),
         QRect(1280, 0, 1280, 1024),
     });
-
-    kwinApp()->start();
-    QVERIFY(applicationStartedSpy.wait());
     const auto outputs = workspace()->outputs();
     QCOMPARE(outputs.count(), 2);
     QCOMPARE(outputs[0]->geometry(), QRect(0, 0, 1280, 1024));
@@ -148,7 +146,7 @@ void TouchInputTest::testTouchHidesCursor()
     QCOMPARE(Cursors::self()->isCursorHidden(), true);
 
     // wheel should also show
-    Test::pointerAxisVertical(1.0, timestamp++);
+    Test::pointerAxisVertical(15.0, timestamp++);
     QCOMPARE(Cursors::self()->isCursorHidden(), false);
 }
 
