@@ -12,12 +12,10 @@
 #include "utils/xcbutils.h"
 // Qt
 #include <QApplication>
-#include <QtTest>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QLoggingCategory>
+#include <QSignalSpy>
+#include <QTest>
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 // xcb
 #include <xcb/xcb.h>
 // system
@@ -65,8 +63,7 @@ void TestClientMachine::initTestCase()
         m_hostName = hostnamebuf;
     }
     addrinfo *res;
-    addrinfo addressHints;
-    memset(&addressHints, 0, sizeof(addressHints));
+    addrinfo addressHints{};
     addressHints.ai_family = PF_UNSPEC;
     addressHints.ai_socktype = SOCK_STREAM;
     addressHints.ai_flags |= AI_CANONNAME;
