@@ -133,7 +133,7 @@ void TestTextInputV3Interface::initTestCase()
     m_display.start();
     QVERIFY(m_display.isRunning());
 
-    m_seat = new SeatInterface(&m_display, this);
+    m_seat = new SeatInterface(&m_display, QStringLiteral("seat0"), this);
     m_seat->setHasKeyboard(true);
 
     m_serverCompositor = new CompositorInterface(&m_display, this);
