@@ -25,10 +25,6 @@ public:
 
     RenderLoop *renderLoop() const override;
 
-    virtual bool present(const std::shared_ptr<OutputFrame> &frame) = 0;
-    virtual DrmOutputLayer *primaryLayer() const = 0;
-    virtual DrmOutputLayer *cursorLayer() const = 0;
-
 protected:
     friend class DrmGpu;
 
