@@ -18,8 +18,10 @@
 namespace KWin
 {
 
-DrmAbstractColorOp::DrmAbstractColorOp(DrmAbstractColorOp *next)
+DrmAbstractColorOp::DrmAbstractColorOp(DrmAbstractColorOp *next, Features features, const QString &name)
     : m_next(next)
+    , m_features(features)
+    , m_name(name)
 {
 }
 
@@ -34,6 +36,21 @@ DrmAbstractColorOp *DrmAbstractColorOp::next() const
 
 static const auto s_disableAmdgpuWorkaround = environmentVariableBoolValue("KWIN_DRM_DISABLE_AMD_GAMMA_WORKAROUND");
 
+bool DrmAbstractColorOp::canBypass() const
+{
+    return m_features & Feature::Bypass;
+}
+
+bool DrmAbstractColorOp::supportsMultipleOps() const
+{
+    return m_features & Feature::MultipleOps;
+}
+
+QString DrmAbstractColorOp::name() const
+{
+    return m_name;
+}
+
 bool DrmAbstractColorOp::matchPipeline(DrmAtomicCommit *commit, const ColorPipeline &pipeline)
 {
     if (m_cachedPipeline && *m_cachedPipeline == pipeline) {
@@ -131,7 +148,7 @@ bool DrmAbstractColorOp::matchPipeline(DrmAtomicCommit *commit, const ColorPipel
 }
 
 DrmLutColorOp::DrmLutColorOp(DrmAbstractColorOp *next, DrmProperty *prop, uint32_t maxSize)
-    : DrmAbstractColorOp(next)
+    : DrmAbstractColorOp(next, Features{Feature::MultipleOps} | Feature::Bypass, QStringLiteral("1D LUT"))
     , m_prop(prop)
     , m_maxSize(maxSize)
     , m_components(m_maxSize)
@@ -193,7 +210,7 @@ void DrmLutColorOp::bypass(DrmAtomicCommit *commit)
 }
 
 LegacyMatrixColorOp::LegacyMatrixColorOp(DrmAbstractColorOp *next, DrmProperty *prop)
-    : DrmAbstractColorOp(next)
+    : DrmAbstractColorOp(next, Features{Feature::MultipleOps} | Feature::Bypass, QStringLiteral("legacy matrix"))
     , m_prop(prop)
 {
 }
