@@ -44,16 +44,12 @@ public:
 
     DrmDevice *drmDevice() const override;
 
-    bool present(Output *output, const std::shared_ptr<OutputFrame> &frame) override;
-    void repairPresentation(Output *output) override;
-    OutputLayer *primaryLayer(Output *output) override;
-    OutputLayer *cursorLayer(Output *output) override;
+    QList<OutputLayer *> compatibleOutputLayers(Output *output) override;
 
     void init() override;
-    std::shared_ptr<DrmPipelineLayer> createDrmPlaneLayer(DrmPipeline *pipeline, DrmPlane::TypeIndex type) override;
-    std::shared_ptr<DrmOutputLayer> createLayer(DrmVirtualOutput *output) override;
-
-    std::pair<std::shared_ptr<KWin::GLTexture>, ColorDescription> textureForOutput(Output *requestedOutput) const override;
+    std::unique_ptr<DrmPipelineLayer> createDrmPlaneLayer(DrmPlane *plane) override;
+    std::unique_ptr<DrmPipelineLayer> createDrmPlaneLayer(DrmGpu *gpu, DrmPlane::TypeIndex type) override;
+    std::unique_ptr<DrmOutputLayer> createLayer(DrmVirtualOutput *output) override;
 
     DrmGpu *gpu() const;
 
