@@ -29,9 +29,9 @@ public:
     explicit DrmVirtualOutput(DrmBackend *backend, const QString &name, const QString &description, const QSize &size, qreal scale);
     ~DrmVirtualOutput() override;
 
-    bool present(const std::shared_ptr<OutputFrame> &frame) override;
-    DrmOutputLayer *primaryLayer() const override;
-    DrmOutputLayer *cursorLayer() const override;
+    bool testPresentation(const std::shared_ptr<OutputFrame> &frame) override;
+    bool present(const QList<OutputLayer *> &layersToUpdate, const std::shared_ptr<OutputFrame> &frame) override;
+    DrmOutputLayer *primaryLayer() const;
     void recreateSurface();
 
 private:
