@@ -11,10 +11,10 @@
 #include "core/output.h"
 
 #include <KWayland/Client/xdgshell.h>
-
 #include <QObject>
 #include <QSize>
 #include <QTimer>
+#include <deque>
 
 namespace KWayland
 {
@@ -34,6 +34,8 @@ struct wp_color_management_surface_v1;
 struct wp_fractional_scale_v1;
 struct wp_fractional_scale_v1_listener;
 struct wp_viewport;
+struct wl_callback;
+struct wl_callback_listener;
 
 namespace KWin
 {
@@ -76,7 +78,7 @@ public:
     ~WaylandOutput() override;
 
     RenderLoop *renderLoop() const override;
-    bool updateCursorLayer(std::optional<std::chrono::nanoseconds> allowedVrrDelay) override;
+    bool presentAsync(OutputLayer *layer, std::optional<std::chrono::nanoseconds> allowedVrrDelay) override;
 
     void init(const QSize &pixelSize, qreal scale, bool fullscreen);
 
@@ -89,14 +91,17 @@ public:
     void setDpmsMode(DpmsMode mode) override;
     void updateDpmsMode(DpmsMode dpmsMode);
 
-    void present(const std::shared_ptr<OutputFrame> &frame);
-    void setPrimaryBuffer(wl_buffer *buffer);
+    bool testPresentation(const std::shared_ptr<OutputFrame> &frame) override;
+    bool present(const QList<OutputLayer *> &layersToUpdate, const std::shared_ptr<OutputFrame> &frame) override;
 
     void frameDiscarded();
     void framePresented(std::chrono::nanoseconds timestamp, uint32_t refreshRate);
 
     void applyChanges(const OutputConfiguration &config) override;
 
+    void setOutputLayers(std::vector<std::unique_ptr<OutputLayer>> &&layers);
+    QList<OutputLayer *> outputLayers() const;
+
 private:
     void handleConfigure(const QSize &size, KWayland::Client::XdgShellSurface::States states, quint32 serial);
     void updateWindowTitle();
@@ -105,7 +110,10 @@ private:
 
     static const wp_fractional_scale_v1_listener s_fractionalScaleListener;
     static void handleFractionalScaleChanged(void *data, struct wp_fractional_scale_v1 *wp_fractional_scale_v1, uint32_t scale120);
+    static const wl_callback_listener s_frameCallbackListener;
+    static void handleFrame(void *data, wl_callback *callback, uint32_t time);
 
+    std::vector<std::unique_ptr<OutputLayer>> m_layers;
     std::unique_ptr<RenderLoop> m_renderLoop;
     std::unique_ptr<KWayland::Client::Surface> m_surface;
     std::unique_ptr<KWayland::Client::XdgShellSurface> m_xdgShellSurface;
@@ -116,14 +124,22 @@ private:
     QTimer m_turnOffTimer;
     bool m_hasPointerLock = false;
     bool m_ready = false;
-    std::shared_ptr<OutputFrame> m_frame;
-    wl_buffer *m_presentationBuffer = nullptr;
+    bool m_mapped = false;
+    struct FrameData
+    {
+        explicit FrameData(const std::shared_ptr<OutputFrame> &frame, struct wp_presentation_feedback *presentationFeedback, struct wl_callback *frameCallback);
+        FrameData(FrameData &&move);
+        ~FrameData();
+
+        std::shared_ptr<OutputFrame> outputFrame;
+        wp_presentation_feedback *presentationFeedback;
+        wl_callback *frameCallback;
+        std::optional<std::chrono::steady_clock::time_point> frameCallbackTime;
+    };
+    std::deque<FrameData> m_frames;
     quint32 m_pendingConfigureSerial = 0;
     QSize m_pendingConfigureSize;
     QTimer m_configureThrottleTimer;
-    wp_presentation_feedback *m_presentationFeedback = nullptr;
-    wp_tearing_control_v1 *m_tearingControl = nullptr;
-    wp_color_management_surface_v1 *m_colorSurface = nullptr;
     std::unique_ptr<ColorSurfaceFeedback> m_colorSurfaceFeedback;
     wp_fractional_scale_v1 *m_fractionalScale = nullptr;
     wp_viewport *m_viewport = nullptr;
