@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include "libkwineffects/kwinglobals.h"
+#include "effect/globals.h"
 
 #include <QObject>
 #include <memory>
