@@ -25,9 +25,10 @@ public:
     Capabilities capabilities() const override;
     QString seat() const override;
     uint terminal() const override;
-    int openRestricted(const QString &fileName) override;
+    std::expected<int, Error> openRestricted(const QString &fileName) override;
     void closeRestricted(int fileDescriptor) override;
     void switchTo(uint terminal) override;
+    FileDescriptor delaySleep(const QString &reason) override;
 
 private Q_SLOTS:
     void handleResumeDevice(uint major, uint minor, QDBusUnixFileDescriptor fileDescriptor);
