@@ -7,10 +7,10 @@
 #include "previewbridge.h"
 #include "previewclient.h"
 #include "previewsettings.h"
-#include <KDecoration2/DecoratedClient>
-#include <KDecoration2/Decoration>
-#include <KDecoration2/DecorationSettings>
-#include <KDecoration2/DecorationShadow>
+#include <KDecoration3/DecoratedWindow>
+#include <KDecoration3/Decoration>
+#include <KDecoration3/DecorationSettings>
+#include <KDecoration3/DecorationShadow>
 #include <QCoreApplication>
 #include <QCursor>
 #include <QPainter>
@@ -21,7 +21,7 @@
 
 #include <QDebug>
 
-namespace KDecoration2
+namespace KDecoration3
 {
 namespace Preview
 {
@@ -55,7 +55,9 @@ void PreviewItem::componentComplete()
     createDecoration();
     if (m_decoration) {
         m_decoration->setSettings(m_settings->settings());
+        m_decoration->create();
         m_decoration->init();
+        m_decoration->apply(m_decoration->nextState()->clone());
         syncSize();
     }
 }
@@ -146,27 +148,27 @@ void PreviewItem::paintShadow(QPainter *painter, int &paddingLeft, int &paddingR
     const QRect outerRect(-paddingLeft, -paddingTop, width(), height());
     const QRect shadowRect(shadowPixmap.rect());
 
-    const QSize topLeftSize(shadow->topLeftGeometry().size());
-    QRect topLeftTarget(
-        QPoint(outerRect.x(), outerRect.y()),
+    const QSizeF topLeftSize(shadow->topLeftGeometry().size());
+    QRectF topLeftTarget(
+        QPointF(outerRect.x(), outerRect.y()),
         topLeftSize);
 
-    const QSize topRightSize(shadow->topRightGeometry().size());
-    QRect topRightTarget(
-        QPoint(outerRect.x() + outerRect.width() - topRightSize.width(),
-               outerRect.y()),
+    const QSizeF topRightSize(shadow->topRightGeometry().size());
+    QRectF topRightTarget(
+        QPointF(outerRect.x() + outerRect.width() - topRightSize.width(),
+                outerRect.y()),
         topRightSize);
 
-    const QSize bottomRightSize(shadow->bottomRightGeometry().size());
-    QRect bottomRightTarget(
-        QPoint(outerRect.x() + outerRect.width() - bottomRightSize.width(),
-               outerRect.y() + outerRect.height() - bottomRightSize.height()),
+    const QSizeF bottomRightSize(shadow->bottomRightGeometry().size());
+    QRectF bottomRightTarget(
+        QPointF(outerRect.x() + outerRect.width() - bottomRightSize.width(),
+                outerRect.y() + outerRect.height() - bottomRightSize.height()),
         bottomRightSize);
 
-    const QSize bottomLeftSize(shadow->bottomLeftGeometry().size());
-    QRect bottomLeftTarget(
-        QPoint(outerRect.x(),
-               outerRect.y() + outerRect.height() - bottomLeftSize.height()),
+    const QSizeF bottomLeftSize(shadow->bottomLeftGeometry().size());
+    QRectF bottomLeftTarget(
+        QPointF(outerRect.x(),
+                outerRect.y() + outerRect.height() - bottomLeftSize.height()),
         bottomLeftSize);
 
     // Re-distribute the corner tiles so no one of them is overlapping with others.
@@ -211,60 +213,60 @@ void PreviewItem::paintShadow(QPainter *painter, int &paddingLeft, int &paddingR
     painter->translate(paddingLeft, paddingTop);
 
     painter->drawImage(topLeftTarget, shadowPixmap,
-                       QRect(QPoint(0, 0), topLeftTarget.size()));
+                       QRectF(QPointF(0, 0), topLeftTarget.size()));
 
     painter->drawImage(topRightTarget, shadowPixmap,
-                       QRect(QPoint(shadowRect.width() - topRightTarget.width(), 0),
-                             topRightTarget.size()));
+                       QRectF(QPointF(shadowRect.width() - topRightTarget.width(), 0),
+                              topRightTarget.size()));
 
     painter->drawImage(bottomRightTarget, shadowPixmap,
-                       QRect(QPoint(shadowRect.width() - bottomRightTarget.width(),
-                                    shadowRect.height() - bottomRightTarget.height()),
-                             bottomRightTarget.size()));
+                       QRectF(QPointF(shadowRect.width() - bottomRightTarget.width(),
+                                      shadowRect.height() - bottomRightTarget.height()),
+                              bottomRightTarget.size()));
 
     painter->drawImage(bottomLeftTarget, shadowPixmap,
-                       QRect(QPoint(0, shadowRect.height() - bottomLeftTarget.height()),
-                             bottomLeftTarget.size()));
+                       QRectF(QPointF(0, shadowRect.height() - bottomLeftTarget.height()),
+                              bottomLeftTarget.size()));
 
     if (drawTop) {
-        QRect topTarget(topLeftTarget.x() + topLeftTarget.width(),
-                        topLeftTarget.y(),
-                        topRightTarget.x() - topLeftTarget.x() - topLeftTarget.width(),
-                        topRightTarget.height());
-        QRect topSource(shadow->topGeometry());
+        QRectF topTarget(topLeftTarget.x() + topLeftTarget.width(),
+                         topLeftTarget.y(),
+                         topRightTarget.x() - topLeftTarget.x() - topLeftTarget.width(),
+                         topRightTarget.height());
+        QRectF topSource(shadow->topGeometry());
         topSource.setHeight(topTarget.height());
         topSource.moveTop(shadowRect.top());
         painter->drawImage(topTarget, shadowPixmap, topSource);
     }
 
     if (drawRight) {
-        QRect rightTarget(topRightTarget.x(),
-                          topRightTarget.y() + topRightTarget.height(),
-                          topRightTarget.width(),
-                          bottomRightTarget.y() - topRightTarget.y() - topRightTarget.height());
-        QRect rightSource(shadow->rightGeometry());
+        QRectF rightTarget(topRightTarget.x(),
+                           topRightTarget.y() + topRightTarget.height(),
+                           topRightTarget.width(),
+                           bottomRightTarget.y() - topRightTarget.y() - topRightTarget.height());
+        QRectF rightSource(shadow->rightGeometry());
         rightSource.setWidth(rightTarget.width());
         rightSource.moveRight(shadowRect.right());
         painter->drawImage(rightTarget, shadowPixmap, rightSource);
     }
 
     if (drawBottom) {
-        QRect bottomTarget(bottomLeftTarget.x() + bottomLeftTarget.width(),
-                           bottomLeftTarget.y(),
-                           bottomRightTarget.x() - bottomLeftTarget.x() - bottomLeftTarget.width(),
-                           bottomRightTarget.height());
-        QRect bottomSource(shadow->bottomGeometry());
+        QRectF bottomTarget(bottomLeftTarget.x() + bottomLeftTarget.width(),
+                            bottomLeftTarget.y(),
+                            bottomRightTarget.x() - bottomLeftTarget.x() - bottomLeftTarget.width(),
+                            bottomRightTarget.height());
+        QRectF bottomSource(shadow->bottomGeometry());
         bottomSource.setHeight(bottomTarget.height());
         bottomSource.moveBottom(shadowRect.bottom());
         painter->drawImage(bottomTarget, shadowPixmap, bottomSource);
     }
 
     if (drawLeft) {
-        QRect leftTarget(topLeftTarget.x(),
-                         topLeftTarget.y() + topLeftTarget.height(),
-                         topLeftTarget.width(),
-                         bottomLeftTarget.y() - topLeftTarget.y() - topLeftTarget.height());
-        QRect leftSource(shadow->leftGeometry());
+        QRectF leftTarget(topLeftTarget.x(),
+                          topLeftTarget.y() + topLeftTarget.height(),
+                          topLeftTarget.width(),
+                          bottomLeftTarget.y() - topLeftTarget.y() - topLeftTarget.height());
+        QRectF leftSource(shadow->leftGeometry());
         leftSource.setWidth(leftTarget.width());
         leftSource.moveLeft(shadowRect.left());
         painter->drawImage(leftTarget, shadowPixmap, leftSource);
@@ -275,7 +277,7 @@ static QMouseEvent cloneEventWithPadding(QMouseEvent *event, int paddingLeft, in
 {
     return QMouseEvent(
         event->type(),
-        event->localPos() - QPointF(paddingLeft, paddingTop),
+        event->position() - QPointF(paddingLeft, paddingTop),
         event->button(),
         event->buttons(),
         event->modifiers());
@@ -285,7 +287,7 @@ static QHoverEvent cloneEventWithPadding(QHoverEvent *event, int paddingLeft, in
 {
     return QHoverEvent(
         event->type(),
-        event->posF() - QPointF(paddingLeft, paddingTop),
+        event->position() - QPointF(paddingLeft, paddingTop),
         event->oldPosF() - QPointF(paddingLeft, paddingTop),
         event->modifiers());
 }
