@@ -21,6 +21,7 @@ class KTitleBarActionsConfig;
 class KWindowActionsConfig;
 class KAdvancedConfig;
 class KMovingConfig;
+class KPipConfig;
 
 class KWinOptions : public KCModule
 {
@@ -44,6 +45,7 @@ private:
     KWindowActionsConfig *mWindowActions;
     KMovingConfig *mMoving;
     KAdvancedConfig *mAdvanced;
+    KPipConfig *mPip = nullptr;
 
     KWinOptionsSettings *mSettings;
 };
