@@ -26,6 +26,7 @@ namespace KWin
 KeyboardLayout::KeyboardLayout(Xkb *xkb, const KSharedConfigPtr &config)
     : QObject()
     , m_xkb(xkb)
+    , m_configWatcher(KConfigWatcher::create(config))
     , m_configGroup(config->group(QStringLiteral("Layout")))
 {
 }
@@ -59,12 +60,7 @@ void KeyboardLayout::init()
 
     connect(switchLastUsedKeyboardAction, &QAction::triggered, this, &KeyboardLayout::switchToLastUsedLayout);
 
-    QDBusConnection::sessionBus().connect(QString(),
-                                          QStringLiteral("/Layouts"),
-                                          QStringLiteral("org.kde.keyboard"),
-                                          QStringLiteral("reloadConfig"),
-                                          this,
-                                          SLOT(reconfigure()));
+    connect(m_configWatcher.data(), &KConfigWatcher::configChanged, this, &KeyboardLayout::handleXkbConfigChanged);
 
     reconfigure();
 
@@ -106,6 +102,13 @@ void KeyboardLayout::switchToLastUsedLayout()
     }
 }
 
+void KeyboardLayout::handleXkbConfigChanged(const KConfigGroup &group)
+{
+    if (group.name() == QStringLiteral("Layout")) {
+        reconfigure();
+    }
+}
+
 void KeyboardLayout::reconfigure()
 {
     if (m_configGroup.isValid()) {
@@ -134,6 +137,7 @@ void KeyboardLayout::loadShortcuts()
     qDeleteAll(m_layoutShortcuts);
     m_layoutShortcuts.clear();
     const QString componentName = QStringLiteral("KDE Keyboard Layout Switcher");
+    const QString componentDisplayName = i18n("Keyboard Layout Switcher");
     const quint32 count = m_xkb->numberOfLayouts();
     for (uint i = 0; i < count; ++i) {
         // layout name is translated in the action name in keyboard kcm!
@@ -145,6 +149,7 @@ void KeyboardLayout::loadShortcuts()
         QAction *a = new QAction(this);
         a->setObjectName(action);
         a->setProperty("componentName", componentName);
+        a->setProperty("componentDisplayName", componentDisplayName);
         connect(a, &QAction::triggered, this,
                 std::bind(&KeyboardLayout::switchToLayout, this, i));
         KGlobalAccel::self()->setShortcut(a, shortcuts, KGlobalAccel::Autoloading);
