@@ -46,14 +46,17 @@ public:
     int uniformLocation(const char *name);
 
     bool setUniform(const char *name, float value);
+    bool setUniform(const char *name, double value);
     bool setUniform(const char *name, int value);
     bool setUniform(const char *name, const QVector2D &value);
     bool setUniform(const char *name, const QVector3D &value);
     bool setUniform(const char *name, const QVector4D &value);
+    bool setUniform(const char *name, const QMatrix3x3 &value);
     bool setUniform(const char *name, const QMatrix4x4 &value);
     bool setUniform(const char *name, const QColor &color);
 
     bool setUniform(int location, float value);
+    bool setUniform(int location, double value);
     bool setUniform(int location, int value);
     bool setUniform(int location, int xValue, int yValue, int zValue);
     bool setUniform(int location, const QVector2D &value);
@@ -82,11 +85,16 @@ public:
         WindowTransformation,
         ScreenTransformation,
         ColorimetryTransformation,
+        DestinationToLMS,
+        LMSToDestination,
+        YuvToRgb,
         MatrixCount
     };
 
     enum class Vec2Uniform {
         Offset,
+        SourceTransferFunctionParams,
+        DestinationTransferFunctionParams,
         Vec2UniformCount
     };
 
@@ -96,13 +104,17 @@ public:
 
     enum class Vec4Uniform {
         ModulationConstant,
+        Box,
+        CornerRadius,
         Vec4UniformCount
     };
 
     enum class FloatUniform {
         Saturation,
-        MaxHdrBrightness,
-        SdrBrightness,
+        MaxDestinationLuminance,
+        SourceReferenceLuminance,
+        DestinationReferenceLuminance,
+        MaxTonemappingLuminance,
         FloatUniformCount
     };
 
@@ -114,6 +126,7 @@ public:
         DestinationNamedTransferFunction,
         Sampler,
         Sampler1,
+        Thickness,
         IntUniformCount
     };
 
@@ -132,9 +145,7 @@ public:
     bool setUniform(ColorUniform uniform, const QVector4D &value);
     bool setUniform(ColorUniform uniform, const QColor &value);
 
-    bool setColorspaceUniforms(const ColorDescription &src, const ColorDescription &dst);
-    bool setColorspaceUniformsFromSRGB(const ColorDescription &dst);
-    bool setColorspaceUniformsToSRGB(const ColorDescription &src);
+    void setColorspaceUniforms(const std::shared_ptr<ColorDescription> &src, const std::shared_ptr<ColorDescription> &dst, RenderingIntent intent);
 
 protected:
     GLShader(unsigned int flags = NoFlags);
