@@ -29,11 +29,11 @@ public:
 
     bool provides(Feature feature) override;
     bool perform(Feature feature, const QVariantList &arguments) override;
+    void reconfigure(ReconfigureFlags flags) override;
     Q_SCRIPTABLE void highlightWindows(const QStringList &windows);
 
 public Q_SLOTS:
     void slotWindowAdded(KWin::EffectWindow *w);
-    void slotWindowClosed(KWin::EffectWindow *w);
     void slotWindowDeleted(KWin::EffectWindow *w);
 
 private:
@@ -51,8 +51,6 @@ private:
     QHash<EffectWindow *, quint64> m_animations;
     QEasingCurve m_easingCurve;
     int m_fadeDuration;
-    EffectWindow *m_monitorWindow;
-    QList<WId> m_highlightedIds;
     float m_ghostOpacity = 0;
 };
 
