@@ -4,7 +4,6 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include "main.h"
 #include "plugin.h"
 
 #include "keynotification.h"
@@ -18,13 +17,7 @@ class KWIN_EXPORT KeyNotificationFactory : public KWin::PluginFactory
 public:
     std::unique_ptr<KWin::Plugin> create() const override
     {
-        switch (KWin::kwinApp()->operationMode()) {
-        case KWin::Application::OperationModeWayland:
-            return std::make_unique<KWin::KeyNotificationPlugin>();
-        case KWin::Application::OperationModeX11:
-        default:
-            return nullptr;
-        }
+        return std::make_unique<KWin::KeyNotificationPlugin>();
     }
 };
 
