@@ -10,8 +10,7 @@
 #include "offscreensurface.h"
 #include "core/outputbackend.h"
 #include "eglhelpers.h"
-#include "main.h"
-#include "platformsupport/scenes/opengl/egldisplay.h"
+#include "opengl/egldisplay.h"
 
 #include <QOffscreenSurface>
 
