@@ -93,8 +93,6 @@ void Window::setVisible(bool visible)
     } else {
         unmap();
     }
-
-    QPlatformWindow::setVisible(visible);
 }
 
 QSurfaceFormat Window::format() const
@@ -119,16 +117,12 @@ void Window::lower()
 
 void Window::setGeometry(const QRect &rect)
 {
-    const QRect oldGeometry = geometry();
-    QPlatformWindow::setGeometry(rect);
-
-    if (window()->isVisible() && rect.isValid()) {
-        QWindowSystemInterface::handleGeometryChange(window(), geometry());
+    if (m_handle) {
+        m_handle->moveResize(rect);
+        return;
     }
 
-    if (isExposed() && oldGeometry.size() != rect.size()) {
-        QWindowSystemInterface::handleExposeEvent(window(), QRect(QPoint(), rect.size()));
-    }
+    QWindowSystemInterface::handleGeometryChange(window(), rect);
 }
 
 WId Window::winId() const
@@ -141,6 +135,11 @@ qreal Window::devicePixelRatio() const
     return m_scale;
 }
 
+bool Window::isExposed() const
+{
+    return m_exposed;
+}
+
 InternalWindow *Window::internalWindow() const
 {
     return m_handle;
@@ -153,6 +152,9 @@ void Window::map()
     }
 
     m_handle = new InternalWindow(window());
+
+    m_exposed = true;
+    QWindowSystemInterface::handleExposeEvent(window(), QRect(QPoint(), geometry().size()));
 }
 
 void Window::unmap()
@@ -165,6 +167,9 @@ void Window::unmap()
     m_handle = nullptr;
 
     invalidateSurface();
+
+    m_exposed = false;
+    QWindowSystemInterface::handleExposeEvent(window(), QRect());
 }
 
 }
