@@ -22,15 +22,15 @@ namespace KWin
 /*
  * How it Works:
  *
- * This effect doesn't change the current desktop, only recieves changes from the VirtualDesktopManager.
- * The only visually aparent inputs are desktopChanged() and desktopChanging().
+ * This effect doesn't change the current desktop, only receives changes from the VirtualDesktopManager.
+ * The only visually apparent inputs are desktopChanged() and desktopChanging().
  *
- * When responding to desktopChanging(), the draw position is only affected by what's recieved from there.
+ * When responding to desktopChanging(), the draw position is only affected by what's received from there.
  * After desktopChanging() is done, or without desktopChanging() having been called at all, desktopChanged() is called.
  * The desktopChanged() function configures the m_startPos and m_endPos for the animation, and the duration.
  *
  * m_currentPosition and everything else not labeled "drawCoordinate" uses desktops as a unit.
- * Exmp: 1.2 means the dekstop at index 1 shifted over by .2 desktops.
+ * Exmp: 1.2 means the desktop at index 1 shifted over by .2 desktops.
  * All coords must be positive.
  *
  * For the wrapping effect, the render loop has to handle desktop coordinates larger than the total grid's width.
@@ -75,7 +75,6 @@ public:
 private Q_SLOTS:
     void desktopChanged(VirtualDesktop *old, VirtualDesktop *current, EffectWindow *with);
     void desktopChanging(VirtualDesktop *old, QPointF desktopOffset, EffectWindow *with);
-    void desktopMoved();
     void desktopChangingCancelled();
     void windowAdded(EffectWindow *w);
     void windowDeleted(EffectWindow *w);
@@ -90,7 +89,7 @@ private:
     QPointF forcePositivePosition(QPointF p) const;
     void optimizePath(); // Find the best path to target desktop
 
-    void startAnimation(VirtualDesktop *old, VirtualDesktop *current, EffectWindow *movingWindow = nullptr);
+    void startAnimation(const QPointF &oldPos, VirtualDesktop *current, EffectWindow *movingWindow = nullptr);
     void prepareSwitching();
     void finishedSwitching();
 
@@ -114,12 +113,14 @@ private:
     QPointF m_startPos;
     QPointF m_endPos;
 
+    QPointF m_gesturePos;
+
     EffectWindow *m_movingWindow = nullptr;
     std::chrono::milliseconds m_lastPresentTime = std::chrono::milliseconds::zero();
-    QPointF m_currentPosition; // Should always be kept up to date with where on the grid we're seeing.
 
     struct
     {
+        QPointF position;
         bool wrap;
         QList<VirtualDesktop *> visibleDesktops;
     } m_paintCtx;
