@@ -6,7 +6,9 @@
 
 #pragma once
 
-#include "libkwineffects/kwinquickeffect.h"
+#include "effect/quickeffect.h"
+
+#include <QAction>
 
 namespace KWin
 {
