@@ -41,7 +41,7 @@ public:
     TrackMouseEffect();
     ~TrackMouseEffect() override;
 
-    void prePaintScreen(ScreenPrePaintData &data, std::chrono::milliseconds presentTime) override;
+    void postPaintScreen() override;
     void reconfigure(ReconfigureFlags) override;
     bool isActive() const override;
 
