@@ -12,7 +12,7 @@
 
 #include "cursor.h"
 #include "input.h"
-#include "utils/xcursortheme.h"
+#include "utils/cursortheme.h"
 
 #include <QElapsedTimer>
 #include <QObject>
@@ -35,7 +35,7 @@ class SurfaceInterface;
 
 namespace Decoration
 {
-class DecoratedClientImpl;
+class DecoratedWindowImpl;
 }
 
 
@@ -48,6 +48,8 @@ public:
 
     void init() override;
 
+    CursorTheme cursorTheme() const; // TODO: Make it a Cursor property
+
     void updateAfterScreenChange();
     bool supportsWarping() const;
     void warp(const QPointF &pos);
@@ -89,11 +91,11 @@ public:
     /**
      * @internal
      */
-    void processButton(uint32_t button, InputRedirection::PointerButtonState state, std::chrono::microseconds time, InputDevice *device = nullptr);
+    void processButton(uint32_t button, PointerButtonState state, std::chrono::microseconds time, InputDevice *device = nullptr);
     /**
      * @internal
      */
-    void processAxis(InputRedirection::PointerAxis axis, qreal delta, qint32 deltaV120, InputRedirection::PointerAxisSource source, std::chrono::microseconds time, InputDevice *device = nullptr);
+    void processAxis(PointerAxis axis, qreal delta, qint32 deltaV120, PointerAxisSource source, bool inverted, std::chrono::microseconds time, InputDevice *device = nullptr);
     /**
      * @internal
      */
@@ -158,7 +160,7 @@ private:
         Warp
     };
     void processMotionInternal(const QPointF &pos, const QPointF &delta, const QPointF &deltaNonAccelerated, std::chrono::microseconds time, InputDevice *device, MotionType type);
-    void cleanupDecoration(Decoration::DecoratedClientImpl *old, Decoration::DecoratedClientImpl *now) override;
+    void cleanupDecoration(Decoration::DecoratedWindowImpl *old, Decoration::DecoratedWindowImpl *now) override;
 
     void focusUpdate(Window *focusOld, Window *focusNow) override;
 
@@ -167,7 +169,7 @@ private:
     void updateOnStartMoveResize();
     void updateToReset();
     void updatePosition(const QPointF &pos, std::chrono::microseconds time);
-    void updateButton(uint32_t button, InputRedirection::PointerButtonState state);
+    void updateButton(uint32_t button, PointerButtonState state);
     QPointF applyEdgeBarrier(const QPointF &pos, const Output *currentOutput, std::chrono::microseconds time);
     EdgeBarrierType edgeBarrierType(const QPointF &pos, const QRectF &lastOutputGeometry) const;
     qreal edgeBarrier(EdgeBarrierType type) const;
@@ -178,7 +180,7 @@ private:
     void breakPointerConstraints(SurfaceInterface *surface);
     CursorImage *m_cursor;
     QPointF m_pos;
-    QHash<uint32_t, InputRedirection::PointerButtonState> m_buttons;
+    QHash<uint32_t, PointerButtonState> m_buttons;
     Qt::MouseButtons m_qtButtons;
     QMetaObject::Connection m_focusGeometryConnection;
     QMetaObject::Connection m_constraintsConnection;
@@ -204,7 +206,7 @@ class WaylandCursorImage : public QObject
 public:
     explicit WaylandCursorImage(QObject *parent = nullptr);
 
-    KXcursorTheme theme() const;
+    CursorTheme theme() const;
 
 Q_SIGNALS:
     void themeChanged();
@@ -212,7 +214,7 @@ Q_SIGNALS:
 private:
     void updateCursorTheme();
 
-    KXcursorTheme m_cursorTheme;
+    CursorTheme m_cursorTheme;
 };
 
 class CursorImage : public QObject
@@ -227,12 +229,11 @@ public:
     void setWindowSelectionCursor(const QByteArray &shape);
     void removeWindowSelectionCursor();
 
-    KXcursorTheme theme() const;
+    CursorTheme theme() const;
     CursorSource *source() const;
     void setSource(CursorSource *source);
 
     void updateCursorOutputs(const QPointF &pos);
-    void markAsRendered(std::chrono::milliseconds timestamp);
 
 Q_SIGNALS:
     void changed();
@@ -243,6 +244,7 @@ private:
     void updateDecoration();
     void updateDecorationCursor();
     void updateMoveResize();
+    void updateDragCursor();
 
     void handleFocusedSurfaceChanged();
 
@@ -254,6 +256,7 @@ private:
     std::unique_ptr<ShapeCursorSource> m_fallbackCursor;
     std::unique_ptr<ShapeCursorSource> m_moveResizeCursor;
     std::unique_ptr<ShapeCursorSource> m_windowSelectionCursor;
+    std::unique_ptr<ShapeCursorSource> m_dragCursor;
 
     struct
     {
@@ -268,29 +271,4 @@ private:
         CursorSource *cursor = nullptr;
     } m_serverCursor;
 };
-
-/**
- * @brief Implementation using the InputRedirection framework to get pointer positions.
- *
- * Does not support warping of cursor.
- */
-class InputRedirectionCursor : public KWin::Cursor
-{
-    Q_OBJECT
-public:
-    explicit InputRedirectionCursor();
-    ~InputRedirectionCursor() override;
-
-protected:
-    void doSetPos() override;
-
-private Q_SLOTS:
-    void slotPosChanged(const QPointF &pos);
-    void slotPointerButtonChanged();
-    void slotModifiersChanged(Qt::KeyboardModifiers mods, Qt::KeyboardModifiers oldMods);
-
-private:
-    Qt::MouseButtons m_currentButtons;
-};
-
 }
