@@ -448,6 +448,15 @@ bool ItemTreeView::shouldRenderItem(Item *item) const
     return item == m_item || m_item->isAncestorOf(item);
 }
 
+static void schedulePendingRepaints(RenderView *view, Item *item)
+{
+    view->addRepaint(item->takeRepaints(view));
+    const auto children = item->childItems();
+    for (Item *child : children) {
+        schedulePendingRepaints(view, child);
+    }
+}
+
 void ItemTreeView::setExclusive(bool enable)
 {
     if (m_exclusive == enable) {
@@ -458,7 +467,7 @@ void ItemTreeView::setExclusive(bool enable)
         m_item->scheduleSceneRepaint(m_item->boundingRect());
         // also need to add all the Item's pending repaint regions to the scene,
         // otherwise some required repaints may be missing
-        m_parentView->addRepaint(m_item->takeRepaints(m_parentView));
+        schedulePendingRepaints(m_parentView, m_item);
         m_parentView->addExclusiveView(this);
         if (m_underlay) {
             m_parentView->addUnderlay(this);
