@@ -19,15 +19,14 @@ public:
     TabBoxConfigPrivate()
         : showTabBox(TabBoxConfig::defaultShowTabBox())
         , highlightWindows(TabBoxConfig::defaultHighlightWindow())
-        , tabBoxMode(TabBoxConfig::ClientTabBox)
         , clientDesktopMode(TabBoxConfig::defaultDesktopMode())
         , clientActivitiesMode(TabBoxConfig::defaultActivitiesMode())
         , clientApplicationsMode(TabBoxConfig::defaultApplicationsMode())
+        , orderMinimizedMode(TabBoxConfig::defaultOrderMinimizedMode())
         , clientMinimizedMode(TabBoxConfig::defaultMinimizedMode())
         , showDesktopMode(TabBoxConfig::defaultShowDesktopMode())
         , clientMultiScreenMode(TabBoxConfig::defaultMultiScreenMode())
         , clientSwitchingMode(TabBoxConfig::defaultSwitchingMode())
-        , desktopSwitchingMode(TabBoxConfig::MostRecentlyUsedDesktopSwitching)
         , layoutName(TabBoxConfig::defaultLayoutName())
     {
     }
@@ -37,15 +36,14 @@ public:
     bool showTabBox;
     bool highlightWindows;
 
-    TabBoxConfig::TabBoxMode tabBoxMode;
     TabBoxConfig::ClientDesktopMode clientDesktopMode;
     TabBoxConfig::ClientActivitiesMode clientActivitiesMode;
     TabBoxConfig::ClientApplicationsMode clientApplicationsMode;
+    TabBoxConfig::OrderMinimizedMode orderMinimizedMode;
     TabBoxConfig::ClientMinimizedMode clientMinimizedMode;
     TabBoxConfig::ShowDesktopMode showDesktopMode;
     TabBoxConfig::ClientMultiScreenMode clientMultiScreenMode;
     TabBoxConfig::ClientSwitchingMode clientSwitchingMode;
-    TabBoxConfig::DesktopSwitchingMode desktopSwitchingMode;
     QString layoutName;
 };
 
@@ -63,15 +61,14 @@ TabBoxConfig &TabBoxConfig::operator=(const KWin::TabBox::TabBoxConfig &object)
 {
     d->showTabBox = object.isShowTabBox();
     d->highlightWindows = object.isHighlightWindows();
-    d->tabBoxMode = object.tabBoxMode();
     d->clientDesktopMode = object.clientDesktopMode();
     d->clientActivitiesMode = object.clientActivitiesMode();
     d->clientApplicationsMode = object.clientApplicationsMode();
+    d->orderMinimizedMode = object.orderMinimizedMode();
     d->clientMinimizedMode = object.clientMinimizedMode();
     d->showDesktopMode = object.showDesktopMode();
     d->clientMultiScreenMode = object.clientMultiScreenMode();
     d->clientSwitchingMode = object.clientSwitchingMode();
-    d->desktopSwitchingMode = object.desktopSwitchingMode();
     d->layoutName = object.layoutName();
     return *this;
 }
@@ -96,16 +93,6 @@ bool TabBoxConfig::isShowTabBox() const
     return d->showTabBox;
 }
 
-void TabBoxConfig::setTabBoxMode(TabBoxConfig::TabBoxMode mode)
-{
-    d->tabBoxMode = mode;
-}
-
-TabBoxConfig::TabBoxMode TabBoxConfig::tabBoxMode() const
-{
-    return d->tabBoxMode;
-}
-
 TabBoxConfig::ClientDesktopMode TabBoxConfig::clientDesktopMode() const
 {
     return d->clientDesktopMode;
@@ -136,6 +123,16 @@ void TabBoxConfig::setClientApplicationsMode(ClientApplicationsMode applications
     d->clientApplicationsMode = applicationsMode;
 }
 
+TabBoxConfig::OrderMinimizedMode TabBoxConfig::orderMinimizedMode() const
+{
+    return d->orderMinimizedMode;
+}
+
+void TabBoxConfig::setOrderMinimizedMode(OrderMinimizedMode orderMinimizedMode)
+{
+    d->orderMinimizedMode = orderMinimizedMode;
+}
+
 TabBoxConfig::ClientMinimizedMode TabBoxConfig::clientMinimizedMode() const
 {
     return d->clientMinimizedMode;
@@ -176,16 +173,6 @@ void TabBoxConfig::setClientSwitchingMode(ClientSwitchingMode switchingMode)
     d->clientSwitchingMode = switchingMode;
 }
 
-TabBoxConfig::DesktopSwitchingMode TabBoxConfig::desktopSwitchingMode() const
-{
-    return d->desktopSwitchingMode;
-}
-
-void TabBoxConfig::setDesktopSwitchingMode(DesktopSwitchingMode switchingMode)
-{
-    d->desktopSwitchingMode = switchingMode;
-}
-
 QString &TabBoxConfig::layoutName() const
 {
     return d->layoutName;
