@@ -141,7 +141,7 @@ void LinuxDrmSyncObjSurfaceV1::wp_linux_drm_syncobj_surface_v1_set_release_point
         return;
     }
     const uint64_t point = (uint64_t(point_hi) << 32) | point_lo;
-    SurfaceInterfacePrivate::get(m_surface)->pending->releasePoint = std::make_unique<SyncReleasePoint>(timeline->timeline(), point);
+    SurfaceInterfacePrivate::get(m_surface)->pending->releasePoint = std::make_shared<SyncReleasePoint>(timeline->timeline(), point);
 }
 
 void LinuxDrmSyncObjSurfaceV1::wp_linux_drm_syncobj_surface_v1_destroy_resource(Resource *resource)
