@@ -14,7 +14,9 @@
 #include "effect/globals.h"
 #include "options.h"
 #include "rules.h"
+#include "scene/borderradius.h"
 #include "utils/common.h"
+#include "utils/gravity.h"
 
 #include <functional>
 #include <memory>
@@ -30,6 +32,10 @@
 #include <QTimer>
 #include <QUuid>
 
+#if KWIN_BUILD_X11
+#include <xcb/xcb.h>
+#endif
+
 class QMouseEvent;
 
 namespace KDecoration3
@@ -59,21 +65,26 @@ class DecorationPalette;
 
 using ElectricBorderMode = std::variant<QuickTileMode, MaximizeMode>;
 
+/**
+ * The PlacementCommand type specifies how a window should be placed in the workspace when it's shown.
+ */
+using PlacementCommand = std::variant<QPointF, QRectF, MaximizeMode>;
+
 class KWIN_EXPORT Window : public QObject
 {
     Q_OBJECT
 
     /**
-     * This property holds rectangle that the pixmap or buffer of this Window
+     * This property holds the rectangle that the pixmap or buffer of this Window
      * occupies on the screen. This rectangle includes invisible portions of the
      * window, e.g. client-side drop shadows, etc.
      */
-    Q_PROPERTY(QRectF bufferGeometry READ bufferGeometry)
+    Q_PROPERTY(QRectF bufferGeometry READ bufferGeometry NOTIFY bufferGeometryChanged)
 
     /**
      * The geometry of the Window without frame borders.
      */
-    Q_PROPERTY(QRectF clientGeometry READ clientGeometry)
+    Q_PROPERTY(QRectF clientGeometry READ clientGeometry NOTIFY clientGeometryChanged)
 
     /**
      * This property holds the position of the Window's frame geometry.
@@ -169,7 +180,7 @@ class KWIN_EXPORT Window : public QObject
 
     /**
      * Returns whether the window is a dropdown menu (i.e. a popup directly or indirectly open
-     * from the applications menubar).
+     * from the application's menubar).
      * See _NET_WM_WINDOW_TYPE_DROPDOWN_MENU at https://standards.freedesktop.org/wm-spec/wm-spec-latest.html .
      */
     Q_PROPERTY(bool dropdownMenu READ isDropdownMenu CONSTANT)
@@ -220,7 +231,7 @@ class KWIN_EXPORT Window : public QObject
     Q_PROPERTY(bool dndIcon READ isDNDIcon CONSTANT)
 
     /**
-     * Returns the NETWM window type
+     * Returns the NETWM window type.
      * See https://standards.freedesktop.org/wm-spec/wm-spec-latest.html .
      */
     Q_PROPERTY(WindowType windowType READ windowType CONSTANT)
@@ -238,7 +249,7 @@ class KWIN_EXPORT Window : public QObject
 
     /**
      * Whether the window does not want to be animated on window close.
-     * There are legit reasons for this like a screenshot application which does not want it's
+     * There are legit reasons for this like a screenshot application which does not want its
      * window being captured.
      */
     Q_PROPERTY(bool skipsCloseAnimation READ skipsCloseAnimation WRITE setSkipCloseAnimation NOTIFY skipCloseAnimationChanged)
@@ -338,17 +349,6 @@ class KWIN_EXPORT Window : public QObject
      */
     Q_PROPERTY(bool keepBelow READ keepBelow WRITE setKeepBelow NOTIFY keepBelowChanged)
 
-    /**
-     * Whether the Window can be shaded. The property is evaluated each time it is invoked.
-     * Because of that there is no notify signal.
-     */
-    Q_PROPERTY(bool shadeable READ isShadeable NOTIFY shadeableChanged)
-
-    /**
-     * Whether the Window is shaded.
-     */
-    Q_PROPERTY(bool shade READ isShade WRITE setShade NOTIFY shadeChanged)
-
     /**
      * Whether the Window can be minimized. The property is evaluated each time it is invoked.
      * Because of that there is no notify signal.
@@ -460,7 +460,7 @@ class KWIN_EXPORT Window : public QObject
      * The decision whether a window has a border or not belongs to the window manager.
      * If this property gets abused by application developers, it will be removed again.
      */
-    Q_PROPERTY(bool noBorder READ noBorder WRITE setNoBorder)
+    Q_PROPERTY(bool noBorder READ noBorder WRITE setNoBorder NOTIFY noBorderChanged)
 
     /**
      * Whether the Window provides context help. Mostly needed by decorations to decide whether to
@@ -537,7 +537,7 @@ class KWIN_EXPORT Window : public QObject
      * The color scheme set on this window
      * Absolute file path, or name of palette in the user's config directory following KColorSchemes format.
      * An empty string indicates the default palette from kdeglobals is used.
-     * @note this indicates the colour scheme requested, which might differ from the theme applied if the colorScheme cannot be found
+     * @note This indicates the colour scheme requested, which might differ from the theme applied if the colorScheme cannot be found
      */
     Q_PROPERTY(QString colorScheme READ colorScheme NOTIFY colorSchemeChanged)
 
@@ -551,14 +551,26 @@ class KWIN_EXPORT Window : public QObject
     /**
      * The Tile this window is associated to, if any
      */
-    Q_PROPERTY(KWin::Tile *tile READ requestedTile WRITE requestTile NOTIFY tileChanged)
+    Q_PROPERTY(KWin::Tile *tile READ requestedTile WRITE setTileCompatibility NOTIFY tileChanged)
 
     /**
-     * Returns whether this window is a input method window.
+     * Returns whether this window is an input method window.
      * This is only used for Wayland.
      */
     Q_PROPERTY(bool inputMethod READ isInputMethod)
 
+    /**
+     * A client-provided tag of the window.
+     * Not necessarily unique, but can be used to identify similar windows
+     * across application restarts
+     */
+    Q_PROPERTY(QString tag READ tag NOTIFY tagChanged)
+
+    /**
+     * A client-provided description of the window
+     */
+    Q_PROPERTY(QString description READ description NOTIFY descriptionChanged)
+
 public:
     ~Window() override;
 
@@ -609,6 +621,9 @@ public:
      */
     QMargins frameMargins() const;
 
+    BorderRadius borderRadius() const;
+    void setBorderRadius(const BorderRadius &radius);
+
     virtual QSizeF minSize() const;
     virtual QSizeF maxSize() const;
     QSizeF size() const;
@@ -712,13 +727,23 @@ public:
      */
     void moveResize(const QRectF &geometry);
 
+    /**
+     * Returns @c true if the window has already been placed in the workspace; otherwise returns @c false.
+     */
+    bool isPlaced() const;
+
+    /**
+     * Places the window in the workspace as specified by the @a placement command.
+     */
+    void place(const PlacementCommand &placement);
+
     void growHorizontal();
     void shrinkHorizontal();
     void growVertical();
     void shrinkVertical();
 
-    virtual QRectF resizeWithChecks(const QRectF &geometry, const QSizeF &s) = 0;
-    QRectF keepInArea(QRectF geometry, QRectF area, bool partial = false);
+    virtual QRectF resizeWithChecks(const QRectF &geometry, const QSizeF &s) const = 0;
+    QRectF keepInArea(QRectF geometry, QRectF area, bool partial = false) const;
 
     // prefer isXXX() instead
     virtual WindowType windowType() const = 0;
@@ -750,6 +775,7 @@ public:
     virtual bool isClient() const;
     bool isDeleted() const;
     virtual bool isUnmanaged() const;
+    virtual bool isPictureInPicture() const;
 
     bool isLockScreenOverlay() const;
     void setLockScreenOverlay(bool allowed);
@@ -775,7 +801,7 @@ public:
     void blockActivityUpdates(bool b = true);
 
     /**
-     * Refresh Window's cache of activites
+     * Refresh Window's cache of activities
      * Called when activity daemon status changes
      */
     virtual void checkActivities(){};
@@ -791,17 +817,12 @@ public:
     bool readyForPainting() const; // true if the window has been already painted its contents
     void setOpacity(qreal opacity);
     qreal opacity() const;
-    virtual bool setupCompositing();
-    virtual void finishCompositing();
+    bool setupCompositing();
+    void finishCompositing();
     EffectWindow *effectWindow();
     const EffectWindow *effectWindow() const;
     SurfaceItem *surfaceItem() const;
     WindowItem *windowItem() const;
-    /**
-     * Window will be temporarily painted as if being at the top of the stack.
-     * Only available if Compositor is active, if not active, this method is a no-op.
-     */
-    void elevate(bool elevate);
 
     /**
      * Returns the Shadow associated with this Window or @c null if it has no shadow.
@@ -946,7 +967,6 @@ public:
 
     void cancelAutoRaise();
 
-    virtual void updateMouseGrab();
     /**
      * @returns The caption consisting of captionNormal and captionSuffix
      * @see captionNormal
@@ -974,16 +994,6 @@ public:
     void setHiddenByShowDesktop(bool hidden);
     Window *findModal() const;
     virtual bool isTransient() const;
-    /**
-     * @returns Whether there is a hint available to place the Window on it's parent, default @c false.
-     * @see transientPlacementHint
-     */
-    virtual bool hasTransientPlacementHint() const;
-    /**
-     * Only valid id hasTransientPlacementHint is true
-     * @returns The position the transient wishes to position itself
-     */
-    virtual QRectF transientPlacement() const;
     const Window *transientFor() const;
     Window *transientFor();
     void setTransientFor(Window *transientFor);
@@ -1013,7 +1023,7 @@ public:
     }
     void setShortcut(const QString &cut);
 
-    virtual QRectF iconGeometry() const;
+    QRectF iconGeometry() const;
 
     void setMinimized(bool set);
     bool isMinimized() const
@@ -1062,23 +1072,6 @@ public:
      */
     virtual bool isMovableAcrossScreens() const = 0;
 
-    /**
-     * Returns @c true if the window is shaded and shadeMode is @c ShadeNormal; otherwise returns @c false.
-     */
-    bool isShade() const
-    {
-        return shadeMode() == ShadeNormal;
-    }
-    ShadeMode shadeMode() const; // Prefer isShade()
-    void setShade(bool set);
-    void setShade(ShadeMode mode);
-    void toggleShade();
-    void cancelShadeHoverTimer();
-    /**
-     * Whether the Window can be shaded. Default implementation returns @c false.
-     */
-    virtual bool isShadeable() const;
-
     const WindowRules *rules() const
     {
         return &m_rules;
@@ -1094,22 +1087,12 @@ public:
     bool wantsTabFocus() const;
     virtual bool takeFocus() = 0;
     virtual bool wantsInput() const = 0;
-    /**
-     * Whether a dock window wants input.
-     *
-     * By default KWin doesn't pass focus to a dock window unless a force activate
-     * request is provided.
-     *
-     * This method allows to have dock windows take focus also through flags set on
-     * the window.
-     *
-     * The default implementation returns @c false.
-     */
-    virtual bool dockWantsInput() const;
     void checkWorkspacePosition(QRectF oldGeometry = QRectF(), const VirtualDesktop *oldDesktop = nullptr);
+#if KWIN_BUILD_X11
     virtual xcb_timestamp_t userTime() const;
+#endif
 
-    void keyPressEvent(uint key_code);
+    void keyPressEvent(QKeyCombination key_code);
 
     virtual void pointerEnterEvent(const QPointF &globalPos);
     virtual void pointerLeaveEvent();
@@ -1121,6 +1104,8 @@ public:
     void commitTile(Tile *tile);
     Tile *requestedTile() const;
     void requestTile(Tile *tile);
+    void forgetTile(Tile *tile);
+    void setTileCompatibility(Tile *tile);
 
     void handleQuickTileShortcut(QuickTileMode mode);
     void setQuickTileModeAtCurrentPosition(QuickTileMode mode);
@@ -1184,8 +1169,12 @@ public:
     std::optional<Options::MouseCommand> getMousePressCommand(Qt::MouseButton button) const;
     std::optional<Options::MouseCommand> getMouseReleaseCommand(Qt::MouseButton button) const;
     std::optional<Options::MouseCommand> getWheelCommand(Qt::Orientation orientation) const;
+    bool mousePressCommandConsumesEvent(Options::MouseCommand command) const;
+    /**
+     * @returns whether or not the command consumes the event that triggered it
+     */
     bool performMousePressCommand(Options::MouseCommand, const QPointF &globalPos);
-    bool performMouseReleaseCommand(Options::MouseCommand, const QPointF &globalPos);
+    void performMouseReleaseCommand(Options::MouseCommand, const QPointF &globalPos);
 
     // decoration related
     Qt::Edge titlebarPosition() const;
@@ -1242,7 +1231,7 @@ public:
     QRectF virtualKeyboardGeometry() const;
 
     /**
-     * Sets the geometry of the virtual keyboard, The window may resize itself in order to make space for the keybaord
+     * Sets the geometry of the virtual keyboard, The window may resize itself in order to make space for the keyboard
      * This geometry is in global coordinates
      */
     virtual void setVirtualKeyboardGeometry(const QRectF &geo);
@@ -1347,6 +1336,8 @@ public:
 
     /**
      * Sets the last user usage serial of the surface as @p serial
+     * TODO make the QPA responsible for this, it's only needed
+     * for KWindowSystem / for internal windows
      */
     void setLastUsageSerial(quint32 serial);
     quint32 lastUsageSerial() const;
@@ -1362,8 +1353,14 @@ public:
     OutputTransform preferredBufferTransform() const;
     void setPreferredBufferTransform(OutputTransform transform);
 
-    const ColorDescription &preferredColorDescription() const;
-    void setPreferredColorDescription(const ColorDescription &description);
+    const std::shared_ptr<ColorDescription> &preferredColorDescription() const;
+    void setPreferredColorDescription(const std::shared_ptr<ColorDescription> &description);
+
+    QString tag() const;
+    QString description() const;
+
+    void setActivationToken(const QString &token);
+    QString activationToken() const;
 
 public Q_SLOTS:
     virtual void closeWindow() = 0;
@@ -1373,7 +1370,6 @@ protected Q_SLOTS:
 
 Q_SIGNALS:
     void stackingOrderChanged();
-    void shadeChanged();
     void opacityChanged(KWin::Window *window, qreal oldOpacity);
     void damaged(KWin::Window *window);
     void inputTransformationChanged();
@@ -1421,7 +1417,7 @@ Q_SIGNALS:
     void clientGeometryChanged(const QRectF &oldGeometry);
 
     /**
-     * This signal is emitted when the frame geometry is about to change. the new geometry is not known yet
+     * This signal is emitted when the frame geometry is about to change. The new geometry is not known yet
      */
     void frameGeometryAboutToChange();
 
@@ -1467,7 +1463,6 @@ Q_SIGNALS:
     void interactiveMoveResizeFinished();
     void closeableChanged(bool);
     void minimizeableChanged(bool);
-    void shadeableChanged(bool);
     void maximizeableChanged(bool);
     void desktopFileNameChanged();
     void applicationMenuChanged();
@@ -1484,6 +1479,10 @@ Q_SIGNALS:
     void offscreenRenderingChanged();
     void targetScaleChanged();
     void nextTargetScaleChanged();
+    void noBorderChanged();
+    void tagChanged();
+    void descriptionChanged();
+    void borderRadiusChanged();
 
 protected:
     Window();
@@ -1496,6 +1495,7 @@ protected:
     void autoRaise();
     bool isMostRecentlyRaised() const;
     void markAsDeleted();
+    void markAsPlaced();
     /**
      * Whether the window accepts focus.
      * The difference to wantsInput is that the implementation should not check rules and return
@@ -1523,13 +1523,6 @@ protected:
      * Default implementation does nothing.
      */
     virtual void doSetKeepBelow();
-    /**
-     * Called from setShade() once the shadeMode value got updated, but before the changed signal
-     * is emitted.
-     *
-     * Default implementation does nothing.
-     */
-    virtual void doSetShade(ShadeMode previousShadeMode);
     /**
      * Called from setDeskop once the desktop value got updated, but before the changed signal
      * is emitted.
@@ -1591,7 +1584,7 @@ protected:
     void updateElectricGeometryRestore();
     QRectF quickTileGeometryRestore() const;
     QRectF quickTileGeometry(QuickTileMode mode, const QPointF &pos) const;
-    void updateQuickTileMode(QuickTileMode newMode);
+    void exitQuickTileMode();
 
     // geometry handling
     void checkOffscreenPosition(QRectF *geom, const QRectF &screenArea);
@@ -1720,11 +1713,9 @@ protected:
     /**
      * Called during handling a resize. Implementing subclasses can use this
      * method to perform windowing system specific syncing.
-     *
-     * Default implementation does nothing.
      */
     virtual void doInteractiveResizeSync(const QRectF &rect);
-    QRectF titleBarRect(const QRectF &rect, bool &transposed) const;
+    qreal titlebarThickness() const;
     QRectF nextInteractiveMoveGeometry(const QPointF &global) const;
     QRectF nextInteractiveResizeGeometry(const QPointF &global) const;
     void dontInteractiveMoveResize();
@@ -1741,6 +1732,7 @@ protected:
     void startDecorationDoubleClickTimer();
     void invalidateDecorationDoubleClickTimer();
     void updateDecorationInputShape();
+    void updateDecorationBorderRadius();
 
     void setDesktopFileName(const QString &name);
     QString iconFromDesktopFile() const;
@@ -1754,11 +1746,6 @@ protected:
     QString shortcutCaptionSuffix() const;
     virtual void updateCaption() = 0;
 
-    void startShadeHoverTimer();
-    void startShadeUnhoverTimer();
-    void shadeHover();
-    void shadeUnhover();
-
     // The geometry that the window should be restored when the virtual keyboard closes
     QRectF keyboardGeometryRestore() const;
     void setKeyboardGeometryRestore(const QRectF &geom);
@@ -1774,6 +1761,8 @@ protected:
     void updatePreferredColorDescription();
     void setTargetScale(qreal scale);
 
+    void setDescription(const QString &description);
+
     Output *m_output = nullptr;
     QRectF m_frameGeometry;
     QRectF m_clientGeometry;
@@ -1782,10 +1771,12 @@ protected:
     bool m_hidden = false;
     bool m_hiddenByShowDesktop = false;
 
+    BorderRadius m_borderRadius;
+
     qreal m_nextTargetScale = 1;
     qreal m_targetScale = 1;
     OutputTransform m_preferredBufferTransform = OutputTransform::Normal;
-    ColorDescription m_preferredColorDescription = ColorDescription::sRGB;
+    std::shared_ptr<ColorDescription> m_preferredColorDescription = ColorDescription::sRGB;
 
     int m_refCount = 1;
     QUuid m_internalId;
@@ -1809,14 +1800,13 @@ protected:
     QIcon m_icon;
     bool m_active = false;
     bool m_deleted = false;
+    bool m_placed = false;
     bool m_keepAbove = false;
     bool m_keepBelow = false;
     bool m_demandsAttention = false;
     bool m_minimized = false;
     bool m_suspended = false;
     QTimer *m_autoRaiseTimer = nullptr;
-    QTimer *m_shadeHoverTimer = nullptr;
-    ShadeMode m_shadeMode = ShadeNone;
     QList<VirtualDesktop *> m_desktops;
 
     QStringList m_activityList;
@@ -1892,6 +1882,11 @@ protected:
     bool m_lockScreenOverlay = false;
     uint32_t m_offscreenRenderCount = 0;
     QTimer m_offscreenFramecallbackTimer;
+
+    QString m_tag;
+    QString m_description;
+
+    QString m_activationToken;
 };
 
 inline QRectF Window::bufferGeometry() const
@@ -2059,6 +2054,11 @@ inline bool Window::isInternal() const
     return false;
 }
 
+inline bool Window::isPictureInPicture() const
+{
+    return false;
+}
+
 inline WindowItem *Window::windowItem() const
 {
     return m_windowItem.get();
