@@ -161,6 +161,7 @@ public:
     bool providesContextHelp() const override;
 
     void updateVisibility();
+    bool hiddenPreview() const; ///< Window is mapped in order to get a window pixmap
 
     QString captionNormal() const override
     {
@@ -328,6 +329,7 @@ private:
 
     void internalShow();
     void internalHide();
+    void internalKeep();
     void map();
     void unmap();
 
@@ -362,6 +364,7 @@ private:
         Withdrawn, ///< Not handled, as per ICCCM WithdrawnState
         Mapped, ///< The frame is mapped
         Unmapped, ///< The frame is not mapped
+        Kept ///< The frame should be unmapped, but is kept (For compositing)
     };
     MappingState mapping_state;
 
@@ -537,6 +540,11 @@ inline bool X11Window::hasUserTimeSupport() const
     return info->userTime() != -1U;
 }
 
+inline bool X11Window::hiddenPreview() const
+{
+    return mapping_state == Kept;
+}
+
 inline quint64 X11Window::surfaceSerial() const
 {
     return m_surfaceSerial;
