@@ -36,17 +36,17 @@ private:
     void doHandleXfixesNotify(xcb_xfixes_selection_notify_event_t *event) override;
     void x11OfferLost() override;
     void x11OffersChanged(const QStringList &added, const QStringList &removed) override;
-    /**
-     * Check the current state of the selection and if a source needs
-     * to be created or destroyed.
-     */
-    void checkWlSource();
+
+    void onSelectionChanged();
+    void onActiveWindowChanged();
 
     /**
      * Returns if dsi is managed by our data bridge
      */
     bool ownsSelection(AbstractDataSource *dsi) const;
 
+    bool x11ClientsCanAccessSelection() const;
+
     Q_DISABLE_COPY(Clipboard)
     std::unique_ptr<XwlDataSource> m_selectionSource;
 };
