@@ -6,8 +6,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KWIN_XWL_DRAG
-#define KWIN_XWL_DRAG
+#pragma once
 
 #include <QObject>
 #include <QPoint>
@@ -20,7 +19,6 @@ class Window;
 
 namespace Xwl
 {
-enum class DragEventReply;
 
 /**
  * An ongoing drag operation.
@@ -36,7 +34,7 @@ public:
     static void sendClientMessage(xcb_window_t target, xcb_atom_t type, xcb_client_message_data_t *data);
 
     virtual bool handleClientMessage(xcb_client_message_event_t *event) = 0;
-    virtual DragEventReply moveFilter(Window *target, const QPoint &pos) = 0;
+    virtual bool moveFilter(Window *target, const QPointF &position) = 0;
 
 Q_SIGNALS:
     void finish(Drag *self);
@@ -47,5 +45,3 @@ private:
 
 } // namespace Xwl
 } // namespace KWin
-
-#endif
