@@ -27,7 +27,6 @@ class X11Window;
 namespace Xwl
 {
 class X11Source;
-enum class DragEventReply;
 class Xvisit;
 class Dnd;
 
@@ -38,7 +37,7 @@ class WlToXDrag : public Drag
 
 public:
     explicit WlToXDrag(Dnd *dnd);
-    DragEventReply moveFilter(Window *target) override;
+    bool moveFilter(Window *target, const QPointF &position) override;
     bool handleClientMessage(xcb_client_message_event_t *event) override;
 
 private:
@@ -61,9 +60,10 @@ public:
     bool handleFinished(xcb_client_message_event_t *event);
 
     void sendPosition(const QPointF &globalPos);
+    void enter(const QPointF &globalPos);
     void leave();
 
-    bool finished() const
+    bool isFinished() const
     {
         return m_state.finished;
     }
@@ -72,8 +72,9 @@ public:
         return m_target;
     }
     void drop();
+
 Q_SIGNALS:
-    void finish(Xvisit *self);
+    void finished();
 
 private:
     void sendEnter();
@@ -81,7 +82,6 @@ private:
     void sendLeave();
 
     void receiveOffer();
-    void enter();
 
     void retrieveSupportedActions();
     void determineProposedAction();
@@ -89,15 +89,12 @@ private:
     void setProposedAction();
 
     void doFinish();
-    void stopConnections();
 
     Dnd *const m_dnd;
     X11Window *m_target;
     QPointer<AbstractDataSource> m_dataSource;
     uint32_t m_version = 0;
 
-    QMetaObject::Connection m_motionConnection;
-
     struct
     {
         bool pending = false;
